==> querydsl-parser-0.2-sources.jar: foundation/jpa/querydsl/StateExpression14.java <==
package foundation.jpa.querydsl;

import foundation.rpg.parser.UnexpectedInputException;
import foundation.rpg.parser.Named;

import java.util.Arrays;
import java.util.List;

// Generated visitor pattern based state for grammar parser.
public class StateExpression14 extends StackState<com.querydsl.core.types.Expression, StackState<foundation.rpg.common.symbols.Tilda, StackState<com.querydsl.core.types.Expression, ? extends State>>> {

// NoStack:
// Stack:
    public StateExpression14(foundation.jpa.querydsl.QueryFactory factory, com.querydsl.core.types.Expression node, StackState<foundation.rpg.common.symbols.Tilda, StackState<com.querydsl.core.types.Expression, ? extends State>> prev) {
        super(factory, node, prev);
    }


// Reduce:
    @Override
    public State visitRPar(foundation.rpg.common.symbols.RPar symbol) throws UnexpectedInputException {
        StackState<foundation.rpg.common.symbols.Tilda, StackState<com.querydsl.core.types.Expression, ? extends State>> stack1 = this.getPrev();
		StackState<com.querydsl.core.types.Expression, ? extends State> stack2 = stack1.getPrev();
		State stack3 = stack2.getPrev();
        return stack3.visitRelationalBooleanExpression(getFactory().is(stack2.getNode(), stack1.getNode(), this.getNode())).visitRPar(symbol);
    }

    @Override
    public State visitOr(foundation.rpg.common.symbols.Or symbol) throws UnexpectedInputException {
        StackState<foundation.rpg.common.symbols.Tilda, StackState<com.querydsl.core.types.Expression, ? extends State>> stack1 = this.getPrev();
		StackState<com.querydsl.core.types.Expression, ? extends State> stack2 = stack1.getPrev();
		State stack3 = stack2.getPrev();
        return stack3.visitRelationalBooleanExpression(getFactory().is(stack2.getNode(), stack1.getNode(), this.getNode())).visitOr(symbol);
    }

    @Override
    public State visitAnd(foundation.rpg.common.symbols.And symbol) throws UnexpectedInputException {
        StackState<foundation.rpg.common.symbols.Tilda, StackState<com.querydsl.core.types.Expression, ? extends State>> stack1 = this.getPrev();
		StackState<com.querydsl.core.types.Expression, ? extends State> stack2 = stack1.getPrev();
		State stack3 = stack2.getPrev();
        return stack3.visitRelationalBooleanExpression(getFactory().is(stack2.getNode(), stack1.getNode(), this.getNode())).visitAnd(symbol);
    }


// Shift:
// Accept:
    @Override
    public List<Object> stack() {
        StackState<foundation.rpg.common.symbols.Tilda, StackState<com.querydsl.core.types.Expression, ? extends State>> stack1 = this.getPrev();
		StackState<com.querydsl.core.types.Expression, ? extends State> stack2 = stack1.getPrev();
		State stack3 = stack2.getPrev();
        return Arrays.asList(stack2.getNode(), stack1.getNode(), this.getNode());
    }

}

==> querydsl-parser-0.5-sources.jar: foundation/jpa/querydsl/StateExpression14.java <==
package foundation.jpa.querydsl;

import foundation.rpg.parser.UnexpectedInputException;
import foundation.rpg.parser.Named;

import java.util.Arrays;
import java.util.List;

// Generated visitor pattern based state for grammar parser.
public class StateExpression14 extends StackState<com.querydsl.core.types.Expression, StackState<foundation.rpg.common.symbols.Equal, StackState<com.querydsl.core.types.Expression, ? extends State>>> {

// NoStack:
// Stack:
    public StateExpression14(foundation.jpa.querydsl.QueryFactory factory, com.querydsl.core.types.Expression node, StackState<foundation.rpg.common.symbols.Equal, StackState<com.querydsl.core.types.Expression, ? extends State>> prev) {
        super(factory, node, prev);
    }


// Reduce:
    @Override
    public State visitRPar(foundation.rpg.common.symbols.RPar symbol) throws UnexpectedInputException {
        StackState<foundation.rpg.common.symbols.Equal, StackState<com.querydsl.core.types.Expression, ? extends State>> stack1 = this.getPrev();
		StackState<com.querydsl.core.types.Expression, ? extends State> stack2 = stack1.getPrev();
		State stack3 = stack2.getPrev();
        return stack3.visitRelationalBooleanExpression(getFactory().is(stack2.getNode(), stack1.getNode(), this.getNode())).visitRPar(symbol);
    }

    @Override
    public State visitOr(foundation.rpg.common.symbols.Or symbol) throws UnexpectedInputException {
        StackState<foundation.rpg.common.symbols.Equal, StackState<com.querydsl.core.types.Expression, ? extends State>> stack1 = this.getPrev();
		StackState<com.querydsl.core.types.Expression, ? extends State> stack2 = stack1.getPrev();
		State stack3 = stack2.getPrev();
        return stack3.visitRelationalBooleanExpression(getFactory().is(stack2.getNode(), stack1.getNode(), this.getNode())).visitOr(symbol);
    }

    @Override
    public State visitAnd(foundation.rpg.common.symbols.And symbol) throws UnexpectedInputException {
        StackState<foundation.rpg.common.symbols.Equal, StackState<com.querydsl.core.types.Expression, ? extends State>> stack1 = this.getPrev();
		StackState<com.querydsl.core.types.Expression, ? extends State> stack2 = stack1.getPrev();
		State stack3 = stack2.getPrev();
        return stack3.visitRelationalBooleanExpression(getFactory().is(stack2.getNode(), stack1.getNode(), this.getNode())).visitAnd(symbol);
    }


// Shift:
// Accept:
    @Override
    public List<Object> stack() {
        StackState<foundation.rpg.common.symbols.Equal, StackState<com.querydsl.core.types.Expression, ? extends State>> stack1 = this.getPrev();
		StackState<com.querydsl.core.types.Expression, ? extends State> stack2 = stack1.getPrev();
		State stack3 = stack2.getPrev();
        return Arrays.asList(stack2.getNode(), stack1.getNode(), this.getNode());
    }

}
